[07/20] futex: Rename hash_futex()

Message ID 20210915141525.047819744@infradead.org
State Not applicable
Headers
Series futex: splitup and waitv syscall |

Checks

Context Check Description
dj/TryBot-apply_patch success Patch applied to master at the time it was sent

Commit Message

Peter Zijlstra Sept. 15, 2021, 2:07 p.m. UTC
  In order to prepare introducing these symbols into the global
namespace; rename:

  s/hash_futex/hash_futex/g

Signed-off-by: Peter Zijlstra (Intel) <peterz@infradead.org>
---
 kernel/futex/core.c |   22 +++++++++++-----------
 1 file changed, 11 insertions(+), 11 deletions(-)
  

Comments

André Almeida Sept. 15, 2021, 3:17 p.m. UTC | #1
Às 11:07 de 15/09/21, Peter Zijlstra escreveu:
> In order to prepare introducing these symbols into the global
> namespace; rename:
> 
>   s/hash_futex/hash_futex/g
> 

I think you meant

   s/hash_futex/futex_hash/g
  
Peter Zijlstra Sept. 15, 2021, 3:22 p.m. UTC | #2
On Wed, Sep 15, 2021 at 12:17:21PM -0300, André Almeida wrote:
> Às 11:07 de 15/09/21, Peter Zijlstra escreveu:
> > In order to prepare introducing these symbols into the global
> > namespace; rename:
> > 
> >   s/hash_futex/hash_futex/g
> > 
> 
> I think you meant
> 
>    s/hash_futex/futex_hash/g

I think so too :-) Clearly typing i hard...
  

Patch

--- a/kernel/futex/core.c
+++ b/kernel/futex/core.c
@@ -279,7 +279,7 @@  struct futex_hash_bucket {
 
 /*
  * The base of the bucket array and its size are always used together
  * (after initialization only in hash_futex()), so ensure that they
  * reside in the same cacheline.
  */
 static struct {
@@ -380,13 +380,13 @@  static inline int hb_waiters_pending(str
 }
 
 /**
  * hash_futex - Return the hash bucket in the global hash
  * @key:	Pointer to the futex key for which the hash is calculated
  *
  * We hash on the keys returned from get_futex_key (see below) and return the
  * corresponding hash bucket in the global hash.
  */
-static struct futex_hash_bucket *hash_futex(union futex_key *key)
+static struct futex_hash_bucket *futex_hash(union futex_key *key)
 {
 	u32 hash = jhash2((u32 *)key, offsetof(typeof(*key), both.offset) / 4,
 			  key->both.offset);
@@ -885,7 +885,7 @@  static void exit_pi_state_list(struct ta
 		next = head->next;
 		pi_state = list_entry(next, struct futex_pi_state, list);
 		key = pi_state->key;
-		hb = hash_futex(&key);
+		hb = futex_hash(&key);
 
 		/*
 		 * We can race against put_pi_state() removing itself from the
@@ -1634,7 +1634,7 @@  int futex_wake(u32 __user *uaddr, unsign
 	if (unlikely(ret != 0))
 		return ret;
 
-	hb = hash_futex(&key);
+	hb = futex_hash(&key);
 
 	/* Make sure we really have tasks to wakeup */
 	if (!hb_waiters_pending(hb))
@@ -1731,8 +1731,8 @@  int futex_wake_op(u32 __user *uaddr1, un
 	if (unlikely(ret != 0))
 		return ret;
 
-	hb1 = hash_futex(&key1);
-	hb2 = hash_futex(&key2);
+	hb1 = futex_hash(&key1);
+	hb2 = futex_hash(&key2);
 
 retry_private:
 	double_lock_hb(hb1, hb2);
@@ -2172,8 +2172,8 @@  int futex_requeue(u32 __user *uaddr1, un
 	if (requeue_pi && match_futex(&key1, &key2))
 		return -EINVAL;
 
-	hb1 = hash_futex(&key1);
-	hb2 = hash_futex(&key2);
+	hb1 = futex_hash(&key1);
+	hb2 = futex_hash(&key2);
 
 retry_private:
 	hb_waiters_inc(hb2);
@@ -2415,7 +2415,7 @@  static inline struct futex_hash_bucket *
 {
 	struct futex_hash_bucket *hb;
 
-	hb = hash_futex(&q->key);
+	hb = futex_hash(&q->key);
 
 	/*
 	 * Increment the counter before taking the lock so that
@@ -3177,7 +3177,7 @@  int futex_unlock_pi(u32 __user *uaddr, u
 	if (ret)
 		return ret;
 
-	hb = hash_futex(&key);
+	hb = futex_hash(&key);
 	spin_lock(&hb->lock);
 
 	/*
@@ -279,7 +279,7 @@  struct futex_hash_bucket {
 /*
  * The base of the bucket array and its size are always used together
- * (after initialization only in hash_futex()), so ensure that they
+ * (after initialization only in futex_hash()), so ensure that they
  * reside in the same cacheline.
  */
@@ -380,13 +380,13 @@  static inline int hb_waiters_pending(str
 
 /**
- * hash_futex - Return the hash bucket in the global hash
+ * futex_hash - Return the hash bucket in the global hash
  * @key:	Pointer to the futex key for which the hash is calculated
  *